
library(dplyr)
library(ggplot2)

#--------------------------------------------------------------------------------------------------
# IMPORT DATA

folder <- "output"
pathEigenvalues <- paste(folder, "phase_eigenvalues.csv", sep='/')
pathMontecarlo <- paste(folder, "phase_montecarlo.csv", sep='/')
pathXi <- paste(folder, "xi.csv", sep='/')

eigenvalues <- data.table::fread(pathEigenvalues)
montecarlo <- data.table::fread(pathMontecarlo)

xi <- data.table::fread(pathXi)
xi <- complex(real = xi$V1, imaginary = xi$V2)

#--------------------------------------------------------------------------------------------------
# ALPHA

# alpha used to reflect distance to xi=0
alpha <- 1 / (1 + Mod(xi)) 
minalpha <- 0.2
alpha <- ifelse(alpha > minalpha, alpha, minalpha)

#--------------------------------------------------------------------------------------------------
# PLOT DATA

# model that will be plotted
model <- montecarlo

# plot axis
plot <- ggplot() +
   theme_light() +
   labs(x = "θ · 𝕽[λ]^½", y="1 / 𝕴[λ]^½") +
   coord_cartesian(xlim = c(353.5, 361.5), ylim = c(2.825e-5, 2.875e-5))

# plots eigenvalues in the background
for(i in 1:(ncol(eigenvalues)/2))
{
   j <- 2*i - 1
   data <- eigenvalues[,j:(j+1)]
   colnames(data) <- c("x", "y")
   plot <- plot + geom_point(data=data, aes(x=x, y=y), colour = 'black', alpha=alpha, size = alpha)
}

# plot tracked eigenvalues
nbTarget <- ncol(model)/2
model_colors <- rainbow(nbTarget)
for(i in 1:nbTarget)
{
   j <- 2*i - 1
   data <- model[,j:(j+1)]
   colnames(data) <- c("x", "y")
   plot <- plot + geom_point(data=data, aes(x=x, y=y), colour = model_colors[i], alpha=alpha, size = 0.5 + alpha)
}

X11()
print(plot)
